XmlNode

Struct XmlNode 

pub struct XmlNode { /* private fields */ }
An XML element node handle. Cloning is cheap (Arc).

Implementations

Source

impl XmlNode

pub fn new(name: &str) -> Self

Create a new named node

pub fn empty() -> Self

Create an empty/null node

pub fn is_empty(&self) -> bool

Check if this is the empty sentinel

pub fn name(&self) -> String

Get the name of this node

pub fn value(&self) -> String

Get the text value of this node

pub fn set_name(&self, name: &str)

Set the name

pub fn set_value(&self, value: &str)

Set the text value

pub fn append_child(&self, name: &str) -> XmlNode

Append a child element with the given name, return the new child

pub fn prepend_child(&self, name: &str) -> XmlNode

Prepend a child element

pub fn append_child_value(&self, name: &str, value: &str) -> XmlNode

Append a child element with name and text value

pub fn prepend_child_value(&self, name: &str, value: &str) -> XmlNode

Prepend a child element with name and text value

pub fn set_child_value(&self, name: &str, value: &str) -> bool

Set the value of a named child (creating it if needed)

pub fn child(&self, name: &str) -> XmlNode

Get a child by name

pub fn child_value(&self, name: &str) -> String

Get the text value of a named child

pub fn child_value_self(&self) -> String

Get the text content (value of first text child or self value)

pub fn first_child(&self) -> XmlNode

Get the first child

pub fn last_child(&self) -> XmlNode

Get the last child

pub fn next_sibling(&self) -> XmlNode

Get next sibling (requires parent)

pub fn next_sibling_named(&self, name: &str) -> XmlNode

Get next sibling with a given name

pub fn previous_sibling(&self) -> XmlNode

Get previous sibling

pub fn previous_sibling_named(&self, name: &str) -> XmlNode

Get previous sibling with a given name

pub fn parent(&self) -> XmlNode

Get parent

pub fn remove_child_named(&self, name: &str)

Remove a child by name

pub fn remove_child(&self, child: &XmlNode)

Remove a specific child node

pub fn deep_clone(&self) -> XmlNode

Deep clone (copy) of this subtree

pub fn append_copy(&self, other: &XmlNode) -> XmlNode

Append a copy of another subtree

pub fn prepend_copy(&self, other: &XmlNode) -> XmlNode

Prepend a copy of another subtree

pub fn to_xml(&self) -> String

Serialize this subtree to XML string

pub fn same_as(&self, other: &XmlNode) -> bool

Check pointer identity